==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/d4e/structYAPFSettings.js <==
var structYAPFSettings =
[
    [ "disable_node_optimization", "dd/d4e/structYAPFSettings.html#ad2860e5662e072e36679472e23a71261", null ],
    [ "max_search_nodes", "dd/d4e/structYAPFSettings.html#a4237f5acba1fdabedd4df9e2f75b8d7b", null ],
    [ "maximum_go_to_depot_penalty", "dd/d4e/structYAPFSettings.html#aee107422789291eb046198d7df5b47c9", null ],
    [ "rail_crossing_penalty", "dd/d4e/structYAPFSettings.html#a7e42459eab57698c726875a2d217a8a1", null ],
    [ "rail_curve45_penalty", "dd/d4e/structYAPFSettings.html#aa42f4d6a7c6cbf90ffccd7839953a769", null ],
    [ "rail_curve90_penalty", "dd/d4e/structYAPFSettings.html#a0f3ea611ea6313ed44cb5893b2e76625", null ],
    [ "rail_depot_reverse_penalty", "dd/d4e/structYAPFSettings.html#a4bcec10e91ddbe9879b6675ae895374e", null ],
    [ "rail_doubleslip_penalty", "dd/d4e/structYAPFSettings.html#a593a3f67e8125daef9ec027bc2013fd3", null ],
    [ "rail_firstred_exit_penalty", "dd/d4e/structYAPFSettings.html#ac3ccfd6deac9d149fcf70ca4830a25e9", null ],
    [ "rail_firstred_penalty", "dd/d4e/structYAPFSettings.html#a01d81b6979f9c2948ec885fe1e8d354e", null ],
    [ "rail_firstred_twoway_eol", "dd/d4e/structYAPFSettings.html#adeddc061423a024ae4a19fded66d1c49", null ],
    [ "rail_lastred_exit_penalty", "dd/d4e/structYAPFSettings.html#a5489dd0b813fe89d7db1e80458b2e950", null ],
    [ "rail_lastred_penalty", "dd/d4e/structYAPFSettings.html#a50d43a438e9a42444af164c7138d122e", null ],
    [ "rail_longer_platform_penalty", "dd/d4e/structYAPFSettings.html#a1129e052ca3110429c31c4d394d84a8a", null ],
    [ "rail_longer_platform_per_tile_penalty", "dd/d4e/structYAPFSettings.html#ab39bfba3e571d4ae5312143326aa4710", null ],
    [ "rail_look_ahead_max_signals", "dd/d4e/structYAPFSettings.html#a600a4d1e63652e412634c035ac59812a", null ],
    [ "rail_look_ahead_signal_p0", "dd/d4e/structYAPFSettings.html#a3218e775200e97a5e216c30d87dfdc9f", null ],
    [ "rail_look_ahead_signal_p1", "dd/d4e/structYAPFSettings.html#a250ba42fc24cc147bc88c4bd47b0fbc2", null ],
    [ "rail_look_ahead_signal_p2", "dd/d4e/structYAPFSettings.html#a3fd9379f9beb55a3878ea32d849ceca5", null ],
    [ "rail_pbs_cross_penalty", "dd/d4e/structYAPFSettings.html#a8992fb063a0cd3a2392b63abcbd37c9e", null ],
    [ "rail_pbs_signal_back_penalty", "dd/d4e/structYAPFSettings.html#a6ca0f085358dac45ff2cda8f32e0e81d", null ],
    [ "rail_pbs_station_penalty", "dd/d4e/structYAPFSettings.html#aef438a0c1cb6a33d002039b9c9d586c1", null ],
    [ "rail_shorter_platform_penalty", "dd/d4e/structYAPFSettings.html#aeb38a384de0cc98e7795865969e4356d", null ],
    [ "rail_shorter_platform_per_tile_penalty", "dd/d4e/structYAPFSettings.html#ab4c919dcab97871cb1226fb65c5d7d05", null ],
    [ "rail_slope_penalty", "dd/d4e/structYAPFSettings.html#a5dc1c35ca5f74041bdd34f9b3bd2ae97", null ],
    [ "rail_station_penalty", "dd/d4e/structYAPFSettings.html#a66179f89675583f72225369df70cf531", null ],
    [ "rail_use_yapf", "dd/d4e/structYAPFSettings.html#a28f24888c2ac3ff09a7017e6e1bb5d98", null ],
    [ "road_crossing_penalty", "dd/d4e/structYAPFSettings.html#ac41cf503fdb6723653c7298b47495ce0", null ],
    [ "road_curve_penalty", "dd/d4e/structYAPFSettings.html#aa7a2dcdbbe40f95142592e64f16730f3", null ],
    [ "road_slope_penalty", "dd/d4e/structYAPFSettings.html#aa4e1247780c61ebf1941f01f100cc996", null ],
    [ "road_stop_bay_occupied_penalty", "dd/d4e/structYAPFSettings.html#ab9d53cb5a6a3452ec1aace40cc10171b", null ],
    [ "road_stop_occupied_penalty", "dd/d4e/structYAPFSettings.html#aa8bd7072c23a7fcf1465309917ec7f35", null ],
    [ "road_stop_penalty", "dd/d4e/structYAPFSettings.html#a5d9a3c679d51551a0d13fbde8163ddf2", null ],
    [ "road_use_yapf", "dd/d4e/structYAPFSettings.html#a329a68c2bbc4c556713566f0f83077e3", null ],
    [ "ship_use_yapf", "dd/d4e/structYAPFSettings.html#aa91227e8353f950392b631cb62ecaaa7", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/d4e/structYAPFSettings.js <==
var structYAPFSettings =
[
    [ "disable_node_optimization", "dd/d4e/structYAPFSettings.html#ad2860e5662e072e36679472e23a71261", null ],
    [ "max_search_nodes", "dd/d4e/structYAPFSettings.html#a4237f5acba1fdabedd4df9e2f75b8d7b", null ],
    [ "maximum_go_to_depot_penalty", "dd/d4e/structYAPFSettings.html#aee107422789291eb046198d7df5b47c9", null ],
    [ "rail_crossing_penalty", "dd/d4e/structYAPFSettings.html#a7e42459eab57698c726875a2d217a8a1", null ],
    [ "rail_curve45_penalty", "dd/d4e/structYAPFSettings.html#aa42f4d6a7c6cbf90ffccd7839953a769", null ],
    [ "rail_curve90_penalty", "dd/d4e/structYAPFSettings.html#a0f3ea611ea6313ed44cb5893b2e76625", null ],
    [ "rail_depot_reverse_penalty", "dd/d4e/structYAPFSettings.html#a4bcec10e91ddbe9879b6675ae895374e", null ],
    [ "rail_doubleslip_penalty", "dd/d4e/structYAPFSettings.html#a593a3f67e8125daef9ec027bc2013fd3", null ],
    [ "rail_firstred_exit_penalty", "dd/d4e/structYAPFSettings.html#ac3ccfd6deac9d149fcf70ca4830a25e9", null ],
    [ "rail_firstred_penalty", "dd/d4e/structYAPFSettings.html#a01d81b6979f9c2948ec885fe1e8d354e", null ],
    [ "rail_firstred_twoway_eol", "dd/d4e/structYAPFSettings.html#adeddc061423a024ae4a19fded66d1c49", null ],
    [ "rail_lastred_exit_penalty", "dd/d4e/structYAPFSettings.html#a5489dd0b813fe89d7db1e80458b2e950", null ],
    [ "rail_lastred_penalty", "dd/d4e/structYAPFSettings.html#a50d43a438e9a42444af164c7138d122e", null ],
    [ "rail_longer_platform_penalty", "dd/d4e/structYAPFSettings.html#a1129e052ca3110429c31c4d394d84a8a", null ],
    [ "rail_longer_platform_per_tile_penalty", "dd/d4e/structYAPFSettings.html#ab39bfba3e571d4ae5312143326aa4710", null ],
    [ "rail_look_ahead_max_signals", "dd/d4e/structYAPFSettings.html#a600a4d1e63652e412634c035ac59812a", null ],
    [ "rail_look_ahead_signal_p0", "dd/d4e/structYAPFSettings.html#a3218e775200e97a5e216c30d87dfdc9f", null ],
    [ "rail_look_ahead_signal_p1", "dd/d4e/structYAPFSettings.html#a250ba42fc24cc147bc88c4bd47b0fbc2", null ],
    [ "rail_look_ahead_signal_p2", "dd/d4e/structYAPFSettings.html#a3fd9379f9beb55a3878ea32d849ceca5", null ],
    [ "rail_pbs_cross_penalty", "dd/d4e/structYAPFSettings.html#a8992fb063a0cd3a2392b63abcbd37c9e", null ],
    [ "rail_pbs_signal_back_penalty", "dd/d4e/structYAPFSettings.html#a6ca0f085358dac45ff2cda8f32e0e81d", null ],
    [ "rail_pbs_station_penalty", "dd/d4e/structYAPFSettings.html#aef438a0c1cb6a33d002039b9c9d586c1", null ],
    [ "rail_shorter_platform_penalty", "dd/d4e/structYAPFSettings.html#aeb38a384de0cc98e7795865969e4356d", null ],
    [ "rail_shorter_platform_per_tile_penalty", "dd/d4e/structYAPFSettings.html#ab4c919dcab97871cb1226fb65c5d7d05", null ],
    [ "rail_slope_penalty", "dd/d4e/structYAPFSettings.html#a5dc1c35ca5f74041bdd34f9b3bd2ae97", null ],
    [ "rail_station_penalty", "dd/d4e/structYAPFSettings.html#a66179f89675583f72225369df70cf531", null ],
    [ "rail_use_yapf", "dd/d4e/structYAPFSettings.html#a28f24888c2ac3ff09a7017e6e1bb5d98", null ],
    [ "road_crossing_penalty", "dd/d4e/structYAPFSettings.html#ac41cf503fdb6723653c7298b47495ce0", null ],
    [ "road_curve_penalty", "dd/d4e/structYAPFSettings.html#aa7a2dcdbbe40f95142592e64f16730f3", null ],
    [ "road_slope_penalty", "dd/d4e/structYAPFSettings.html#aa4e1247780c61ebf1941f01f100cc996", null ],
    [ "road_stop_bay_occupied_penalty", "dd/d4e/structYAPFSettings.html#ab9d53cb5a6a3452ec1aace40cc10171b", null ],
    [ "road_stop_occupied_penalty", "dd/d4e/structYAPFSettings.html#aa8bd7072c23a7fcf1465309917ec7f35", null ],
    [ "road_stop_penalty", "dd/d4e/structYAPFSettings.html#a5d9a3c679d51551a0d13fbde8163ddf2", null ],
    [ "road_use_yapf", "dd/d4e/structYAPFSettings.html#a329a68c2bbc4c556713566f0f83077e3", null ],
    [ "ship_curve45_penalty", "dd/d4e/structYAPFSettings.html#a12e249074aca128ecd69ba2c77e0bffd", null ],
    [ "ship_curve90_penalty", "dd/d4e/structYAPFSettings.html#a4afda39ccabec9654cf49d2da42a17db", null ],
    [ "ship_use_yapf", "dd/d4e/structYAPFSettings.html#aa91227e8353f950392b631cb62ecaaa7", null ]
];
